@@ -18,4 +18,18 @@ class vbParser:
 				if len(self.attributes)==len(self.found_attributes):
 					parse_results.append(self.found_attributes)
 					self.found_attributes={}
-		return parse_results
\ No newline at end of file
+		return parse_results
+	
+	def _parseAdditional(self, file, expression):
+		parse_results=[]
+		first=False
+		for line in file.readlines():
+			try:
+				result=expression.match(line).groups()[1]
+				if first:
+					parse_results.append(result)
+				else:
+					first=True
+			except AttributeError,e:
+				pass
+		return parse_results		
\ No newline at end of file
